==> kinst-0.1.22.tar.gz: kinst-0.1.22/src/install.h <==
/************************************************************************
 * kinst - KDE Application Installer - install.h                        *
 * Copyright (C) 2000  Steffen Sobiech                                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.            *
 ************************************************************************/

#ifndef _INSTALL_H
#define _INSTALL_H

#include "locale.h"
#include "readfile.h"

class tKIFInstall
{
 private:
  QWidget* guiparent;

  tKIFOptions* InstallOptions;
  FILE* InstallCommand_LogFile;
  char Tmp_LogFileName[FILENAME_MAX];
  char* _SourceFileDir;

  int Create_TmpDir();
  int Open_LogFile();
  void Close_LogFile();
  int Read_Line(char* Readed_Line, int length);

 public:

  // Check File/RPM Existance
  // returns :
  // 0 file/RPM doesnt exist
  // 1 file/RPM exists
  int CheckFileExist(char* filename);
  int CheckRPMExist(char* RPM_Name);

  // Install TAR-GZ
  // returns :
  // 0 general failure
  // 1 success
  // 2 source file error
  // 3 write error
  int Install_TGZ(char* TGZ_filename, char* install_to);

  // Install RPM
  // returns :
  // 0 general failure
  // 1 success
  // 2 source file error
  // 3 write error
  int Install_RPM(char* RPM_filename, char* install_to);

  // Install
  // returns :
  // 0 general failure
  // 1 success
  // 2 source file error
  // 3 write error
  // 4 already installed
  int Install(tKIFOptions given_options, char* destfolder);
  int Install(tKIFOptions given_options, char* destfolder, int extnr);

  tKIFInstall(char* SourceFileDir, QWidget* parent);
  ~tKIFInstall();
};

#endif

==> kinst-0.1.24.tar.gz: kinst-0.1.24/src/install.h <==
/************************************************************************
 * kinst - KDE Application Installer - install.h                        *
 * Copyright (C) 2000  Steffen Sobiech                                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.            *
 ************************************************************************/

#ifndef _INSTALL_H
#define _INSTALL_H

#include "locale.h"
#include "readfile.h"
#include "yesnodlg.h"
#include "kiss.h"

class tKIFInstall
{
 private:
  QWidget* guiparent;

  tYesNoDlg* YesNoDlg;

  tKISS* KISS;

  tKIFOptions* InstallOptions;
  FILE* InstallCommand_LogFile;
  char Tmp_LogFileName[FILENAME_MAX];
  char* _SourceFileDir;

  int Create_TmpDir();
  int Open_LogFile();
  void Close_LogFile();
  int Read_Line(char* Readed_Line, int length);

 public:

  // Check File/RPM Existance
  // returns :
  // 0 file/RPM doesnt exist
  // 1 file/RPM exists
  int CheckFileExist(char* filename);
  int CheckRPMExist(char* RPM_Name);

  // Create version tag
  // returns :
  // 0 general failure
  // 1 success
  int CreateVersionTag(char* filename, tKIFOptions opt, int extnr);

  // Compare version
  // returns :
  // 0 installed application is newer or matches new version
  // 1 installed application is older
  int CompareVersion(char* filename, tKIFOptions opt, int extnr);

  // Install TAR-GZ
  // returns :
  // 0 general failure
  // 1 success
  // 2 source file error
  // 3 write error
  int Install_TGZ(char* TGZ_filename, const char* install_to, void* parent);

  // Install RPM
  // returns :
  // 0 general failure
  // 1 success
  // 2 source file error
  // 3 write error
  int Install_RPM(char* RPM_filename, const char* install_to, void* parent);

  // Install
  // returns :
  // 0 general failure
  // 1 success
  // 2 source file error
  // 3 write error
  // 4 already installed
  int Install(tKIFOptions given_options, const char* destfolder, int extnr,
	      void* parent);

  tKIFInstall(char* SourceFileDir, QWidget* parent);
  ~tKIFInstall();
};

#endif
